pub struct TreePopup<'a> { /* private fields */ }Expand description
Popup que envuelve un Tree para mostrar una jerarquía expandible.
Compone un Popup (chrome) con un Tree (árbol).
Hereda la configuración del Tree a través de builders delegados.
Implementations
Sourceimpl<'a> TreePopup<'a>
impl<'a> TreePopup<'a>
pub fn new(nodes: Vec<TreeNode<'a>>) -> Self
pub fn title(self, title: &'a str) -> Self
pub fn cursor_style(self, style: Style) -> Self
pub fn border_color(self, color: Color) -> Self
pub fn border_type(self, bt: BorderType) -> Self
pub fn bg_color(self, color: Color) -> Self
pub fn width(self, w: PopupSize) -> Self
pub fn height(self, h: PopupSize) -> Self
pub fn position(self, x: u16, y: u16) -> Self
pub fn origin(self, x: u16, y: u16) -> Self
pub fn header(self) -> Self
pub fn padding(self, p: u16) -> Self
pub fn indent(self, n: u16) -> Self
pub fn expand_icon(self, icon: &'a str) -> Self
pub fn collapse_icon(self, icon: &'a str) -> Self
pub fn leaf_icon(self, icon: &'a str) -> Self
pub fn highlight_style(self, style: Style) -> Self
pub fn highlight_symbol(self, symbol: &'a str) -> Self
pub fn borders(self, borders: Borders) -> Self
pub fn border_style(self, style: Style) -> Self
pub fn no_background(self) -> Self
pub fn background_dots(self, color: Color, symbol: &str, density: u16) -> Self
pub fn background_pattern(self, pattern: DotPattern) -> Self
pub fn background_spacing(self, density_x: u16, density_y: u16) -> Self
pub fn badges(self, badges: BadgeStack<'a>) -> Self
Sourceimpl<'a> TreePopup<'a>
impl<'a> TreePopup<'a>
Sourcepub fn item_at(
&self,
state: &TreeState,
popup_rect: Rect,
row: u16,
) -> Option<usize>
pub fn item_at( &self, state: &TreeState, popup_rect: Rect, row: u16, ) -> Option<usize>
Map a screen row to the flat visible item index at that position.
Returns None if the row is in the border/header area or beyond the
last visible item.
Sourcepub fn resolve_rect(&self, area: Rect, state: &TreeState) -> Rect
pub fn resolve_rect(&self, area: Rect, state: &TreeState) -> Rect
Resolves the final Rect for this popup within the given area,
using the current tree state for Auto-height resolution.